@@ -29,9 +29,9 @@ apt-get -y install wget
 # Download TOMOYO Linux patches.
 mkdir -p /root/rpmbuild/SOURCES/
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.4-20150505.tar.gz ]
+if [ ! -r ccs-patch-1.8.4-20150721.tar.gz ]
 then
-    wget -O ccs-patch-1.8.4-20150505.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.4-20150505.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.4-20150721.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.4-20150721.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -44,7 +44,7 @@ for i in `awk ' { if ( $1 != "Build-Depends:") next; $1 = ""; n = split($0, a, "
 # Apply patches and create kernel config.
 cd linux-3.13.0/ || die "Can't chdir to linux-3.13.0/ ."
 update_maintainer
-tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.4-20150505.tar.gz || die "Can't extract patch."
+tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.4-20150721.tar.gz || die "Can't extract patch."
 patch -p1 < patches/ccs-patch-3.13-ubuntu-14.04.diff || die "Can't apply patch."
 rm -fR patches/ specs/ || die "Can't delete patch."
 for i in `find debian.master/ -type f -name '*'${ORIGINAL_FLAVOUR}'*'`; do cp -p $i `echo $i | sed -e 's/'${ORIGINAL_FLAVOUR}'/'${NEW_FLAVOUR}'/g'`; done
@@ -65,7 +65,7 @@ patch -p0 << "EOF" || die "Can't patch link-headers."
 +if [ $flavour == "NEW_FLAVOUR" ]
 +then
 +    cd $hdrdir/../../../../$symdir/usr/src/$symdir/include/linux/
-+    for i in sched.h init_task.h security.h ccsecurity.h
++    for i in sched.h init_task.h security.h ccsecurity.h lsm2ccsecurity.h
 +    do
 +	rm -f $hdrdir/include/linux/$i
 +	cp -p $i $hdrdir/include/linux/$i
